### 1.0.0 (unreleased)

#### Upgrade Steps

- **Update your Gemfile**<br>
  Change your Gemfile to use "teaspoon-framework" instead of "teaspoon".<br>
  eg: If you are using Mocha, this would be `gem 'teaspoon-mocha'`

  If you had Teaspoon locked at a specific version, kill the version. You'll now need to reference the version of the framework, instead of the version of Teaspoon.<br>
  eg: If your Gemfile has `gem 'teaspoon', '0.9.1'` and you're using Mocha, you'll want your Gemfile to reference the latest version of Mocha: `gem 'teaspoon-mocha', '2.2.4'`. The teaspoon-mocha gem contains previous versions of Mocha, so even if you're not using version 2.2.4 of Mocha in your `teaspoon_env.rb`, still reference the latest version in your Gemfile and the older version should still work.

- **Update your coverage configuration in teaspoon_env.rb**<br>
  If you use Teaspoon to generate coverage reports with Istanbul, and you use the `suite.no_coverage` to exclude files from coverage, you'll need to migrate that configuration into the `config.coverage` blocks. So if you have:

  ```ruby
  suite.no_coverage += /my_file.js/
  ```

  You should move this into the `coverage` block:

  ```ruby
  config.coverage do |coverage|
    coverage.ignore += /my_file.js/
  end
  ```

  This means that you can no longer exclude things at the suite level. If you had multiple suites with different `no_coverage` configurations, you'll now need to create multiple coverage blocks and specify the coverage you want when using the CLI.
  eg: teaspoon --coverage=[coverage_name]

- **Ensure suite.javascripts and suite.stylesheets are appending asset**<br>
  If you use `suite.javascripts` or `suite.stylesheets`, make sure you're appending assets into the array instead of assigning the array.

  eg: In Teaspoon 0.9.1, you might have:

  ```ruby
  suite.javascripts = ["jasmine/1.3.1", "teaspoon-jasmine", "custom-js-file"]
  ```

  This will fail as "jasmine/1.3.1" and "teaspoon-jasmine" no longer exist. Teaspoon will automatically add the framework assets to the array for you, so you should append assets instead:

  ```ruby
  suite.javascripts += ["custom-js-file"]
  ```

  Likewise for `suite.stylesheets`.

#### Enhancements

* Break frameworks out into individual gems (eg teaspoon-mocha)
* Frameworks (eg mocha, jasmine) can now be registered with core
* Formatters (eg dot, documentation) can now be registered with core
* Drivers (eg phantomjs, selenium) can now be registered with core
* Support for Jasmine 2.0
* Support for Mocha 2.0
* Improved abstractions around how framework events are handled (via responders)
* Can now specify framework version when installing
* Adds `rake teaspoon:info` to show Teaspoon and framework versions
* Backfill support for old versions of frameworks
* Fail faster when teaspoon_env.rb cannot be found
* Lots of refactors to clean things up

#### Bug Fixes

* Fix files excluded from coverage for RequireJS (@davestevens)
* Fix double teaspoon hook (#332)
* Instrument files when config.expand_assets is false (#357)


### 0.9.1 (3/2/15)

* Fixes an issue where suite view was failing
* CI/Linux stability improvement (alphanumeric ordering of spec files)


### 0.9.0 (2/24/15)

#### Enhancements

* Add `expand_assets` suite configuration to control spec compilation
* Provide QUnit tests with a default `equal` message
* Support cli reusing running Rails server
* Add support for Capybara Webkit
* Better support for RequireJS
* Add RSpec HTML formatter

#### Bug Fixes

* Fix qunit 1.14.0 precompile path

#### Removals

* Direct support for Angular


### 0.8.0 (4/18/14)

Configuration has changed considerably, and deprecation warnings have been provided. In general it's probably best to remove your /initializers/teaspoon.rb and reinstall using the generator. Configuration is now consolidated into spec/teaspoon_env.rb. **This can cause a stack level too deep exception unless the teaspoon_env.rb file properly wraps the loading of rails in a `defined?(Rails)` check.**

#### Upgrade Steps

1. backup your `spec/teaspoon_env.rb` file.
2. run the install generator to get the new `teaspoon_env.rb`.
3. migrate your old settings into the new file, noting the changes that might exist.
4. move all settings that you had in `config/initializers/teaspoon.rb` into `spec/teaspoon_env.rb` and delete the initializer.

#### Coverage reports

Coverage has changed in terms of configuration, to allow for different coverage configurations, and they behave a lot like suite configurations now. You can have any number of coverage configurations and can specify which coverage configuration to use from the command line.

```ruby
config.coverage do |coverage|
   coverage.reports = ["text"]
end
config.coverage :CI do |coverage|
   coverage.reports = ["cobertura", "lcov"]
end
config.use_coverage = :CI
```

#### Frameworks

The configuration around which test framework is used for a suite has been changed and improved. Instead of configuring via the `javascripts` directive we're transitioning to a more complete structure with `use_framework`.

You can specify version of test framework with `use_framework` now, which allows for the gem to be updated, while keeping the impact on your specs minimal.

```ruby
suite.use_framework :mocha, "1.10.0"
```

#### Formatters

Running CI with two formatters is easier, as formatters can be sent to file output instead of just $stdout by using > in the formatter name to be used. Just remember to wrap it in a string when you specify it in the CLI -- or all output will be piped to that file.

```
teaspoon --format="dots,junit>/path/to/junit_output.xml"
config.formatters =  ["dots", "junit>/path/to/junit_output.xml"]
```

#### Drivers

Drivers have a more feature complete configuration strategy. For PhantomJS you can provide a string of flags (eg. --debug=true), and the selenium driver can accept a hash (or json string) to specify something other than firefox for instance.
